from setuptools import setup, find_packages

setup(
    name= "aurask_aisk",
    version='0.1.0',
    description=' aithis is a',
    author='code sx',
    author_email='core@ex.com',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
)
